# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from public_api_server_connector_v2.models.billing_type import BillingType

class TestBillingType(unittest.TestCase):
    """BillingType unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testBillingType(self):
        """Test BillingType"""
        # inst = BillingType()

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from public_api_server_connector_v2.models.ipn_order_payment import IpnOrderPayment

class TestIpnOrderPayment(unittest.TestCase):
    """IpnOrderPayment unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> IpnOrderPayment:
        """Test IpnOrderPayment
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `IpnOrderPayment`
        """
        model = IpnOrderPayment()
        if include_optional:
            return IpnOrderPayment(
                marketplace_buyer = public_api_server_connector_v2.models.marketplace_buyer.MarketplaceBuyer(
                    email = '', 
                    first_name = '', 
                    last_name = '', 
                    phone_number = '', 
                    address = null, ),
                course_ids = [
                    56
                    ],
                id = '',
                transaction = public_api_server_connector_v2.models.ipn_transaction.IpnTransaction(
                    amount = 1.337, 
                    id = '', ),
                send_email = True,
                billing_type = 'single_payment',
                access_until = 56,
                occurred_at = 56
            )
        else:
            return IpnOrderPayment(
                marketplace_buyer = public_api_server_connector_v2.models.marketplace_buyer.MarketplaceBuyer(
                    email = '', 
                    first_name = '', 
                    last_name = '', 
                    phone_number = '', 
                    address = null, ),
                course_ids = [
                    56
                    ],
        )
        """

    def testIpnOrderPayment(self):
        """Test IpnOrderPayment"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from public_api_server_connector_v2.api.mediastorage_api import MediastorageApi


class TestMediastorageApi(unittest.IsolatedAsyncioTestCase):
    """MediastorageApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = MediastorageApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_api_key_auth_create_folder(self) -> None:
        """Test case for api_key_auth_create_folder

        Create Folder
        """
        pass

    async def test_api_key_auth_delete_file(self) -> None:
        """Test case for api_key_auth_delete_file

        Delete File
        """
        pass

    async def test_api_key_auth_delete_folder(self) -> None:
        """Test case for api_key_auth_delete_folder

        Delete Folder
        """
        pass

    async def test_api_key_auth_get_all_files_count(self) -> None:
        """Test case for api_key_auth_get_all_files_count

        Get All Files Count
        """
        pass

    async def test_api_key_auth_get_all_folders(self) -> None:
        """Test case for api_key_auth_get_all_folders

        Get All Folders
        """
        pass

    async def test_api_key_auth_get_all_folders_count(self) -> None:
        """Test case for api_key_auth_get_all_folders_count

        Get All Folders Count
        """
        pass

    async def test_api_key_auth_get_file(self) -> None:
        """Test case for api_key_auth_get_file

        Get File
        """
        pass

    async def test_api_key_auth_get_files(self) -> None:
        """Test case for api_key_auth_get_files

        Get Files
        """
        pass

    async def test_api_key_auth_get_files_all(self) -> None:
        """Test case for api_key_auth_get_files_all

        Get Files All
        """
        pass

    async def test_api_key_auth_get_files_count(self) -> None:
        """Test case for api_key_auth_get_files_count

        Get Files Count
        """
        pass

    async def test_api_key_auth_get_folder(self) -> None:
        """Test case for api_key_auth_get_folder

        Get Folder
        """
        pass

    async def test_api_key_auth_get_folders(self) -> None:
        """Test case for api_key_auth_get_folders

        Get Folders
        """
        pass

    async def test_api_key_auth_get_folders_count(self) -> None:
        """Test case for api_key_auth_get_folders_count

        Get Folders Count
        """
        pass

    async def test_api_key_auth_update_file(self) -> None:
        """Test case for api_key_auth_update_file

        Update File
        """
        pass

    async def test_api_key_auth_update_folder(self) -> None:
        """Test case for api_key_auth_update_folder

        Update Folder
        """
        pass

    async def test_api_key_auth_upload_file(self) -> None:
        """Test case for api_key_auth_upload_file

        Upload File
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.0.0+2522689235"

# Define package exports
__all__ = [
    "ApiKeyAuthApi",
    "ApiKeysApi",
    "ApiLogsApi",
    "ApiSpecApi",
    "CoursesApi",
    "GeneralApi",
    "HealthApi",
    "JwtTokenAuthApi",
    "MediastorageApi",
    "OrdersApi",
    "SpecificationApi",
    "V1Api",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "Address",
    "ApiKeyCreate",
    "ApiKeyCreateResponse",
    "ApiKeyGet",
    "ApiKeyPatch",
    "ApiKeyUpdate",
    "ApiLogGet",
    "AttachedFile",
    "AttachedFileCreate",
    "AttachedFileCreateOrUpdate",
    "AttachedFilePatch",
    "AttachedFilesInner",
    "BillingType",
    "ButtonPosition",
    "ButtonSize",
    "ButtonTarget",
    "Category",
    "CategoryMethodOptions",
    "CategoryPermissions",
    "Content",
    "ContentBlock",
    "ContentBlockCreate",
    "ContentBlockPatch",
    "ContentBlockTypeStrEnum",
    "ContentBlockUpdate",
    "ContentBlocksInner",
    "ContentBlocksInner1",
    "Course",
    "CourseAccessTypeStrEnum",
    "CourseContentBlock",
    "CourseCreate",
    "CourseModule",
    "CourseModuleCreate",
    "CourseModulePatch",
    "CourseModuleSimple",
    "CourseModuleUpdate",
    "CourseModuleViewTypeStrEnum",
    "CoursePatch",
    "CoursePaymentTypeStrEnum",
    "CourseSimple",
    "CourseSubmodule",
    "CourseSubmoduleCreate",
    "CourseSubmodulePatch",
    "CourseSubmoduleUpdate",
    "CourseUpdate",
    "File",
    "FileUpdate",
    "FileUploadResult",
    "Folder",
    "FolderCreate",
    "FolderUpdate",
    "HTTPValidationError",
    "HttpMethod",
    "IpnOrderPayment",
    "IpnOrderPaymentResponse",
    "IpnOrderRefund",
    "IpnOrderRefundResponse",
    "IpnTransaction",
    "LessonTypeStrEnum",
    "LocationInner",
    "MarketplaceBuyer",
    "ModuleLesson",
    "ModuleLessonCreate",
    "ModuleLessonPatch",
    "ModuleLessonPatchAttachedFiles",
    "ModuleLessonPatchContent",
    "ModuleLessonSimple",
    "ModuleLessonUpdate",
    "PortalInfo",
    "PortalMemberBase",
    "ResponseWrapper",
    "ResponseWrapperApiKeyCreateResponse",
    "ResponseWrapperApiKeyGet",
    "ResponseWrapperApiLogGet",
    "ResponseWrapperBool",
    "ResponseWrapperCourse",
    "ResponseWrapperCourseModule",
    "ResponseWrapperCourseModuleSimple",
    "ResponseWrapperCourseSimple",
    "ResponseWrapperCourseSubmodule",
    "ResponseWrapperFile",
    "ResponseWrapperFileUploadResult",
    "ResponseWrapperFolder",
    "ResponseWrapperInt",
    "ResponseWrapperIpnOrderPaymentResponse",
    "ResponseWrapperIpnOrderRefundResponse",
    "ResponseWrapperListApiKeyGet",
    "ResponseWrapperListApiLogGet",
    "ResponseWrapperListCategory",
    "ResponseWrapperListContentBlock",
    "ResponseWrapperListCourseModuleSimple",
    "ResponseWrapperListCourseSimple",
    "ResponseWrapperListCourseSubmodule",
    "ResponseWrapperListFile",
    "ResponseWrapperListFolder",
    "ResponseWrapperListModuleLessonSimple",
    "ResponseWrapperListStr",
    "ResponseWrapperModuleLesson",
    "ResponseWrapperModuleLessonSimple",
    "ResponseWrapperTokenInfo",
    "Result",
    "TokenInfo",
    "ValidationError",
]

# import apis into sdk package
from public_api_server_connector_v2.api.api_key_auth_api import ApiKeyAuthApi as ApiKeyAuthApi
from public_api_server_connector_v2.api.api_keys_api import ApiKeysApi as ApiKeysApi
from public_api_server_connector_v2.api.api_logs_api import ApiLogsApi as ApiLogsApi
from public_api_server_connector_v2.api.api_spec_api import ApiSpecApi as ApiSpecApi
from public_api_server_connector_v2.api.courses_api import CoursesApi as CoursesApi
from public_api_server_connector_v2.api.general_api import GeneralApi as GeneralApi
from public_api_server_connector_v2.api.health_api import HealthApi as HealthApi
from public_api_server_connector_v2.api.jwt_token_auth_api import JwtTokenAuthApi as JwtTokenAuthApi
from public_api_server_connector_v2.api.mediastorage_api import MediastorageApi as MediastorageApi
from public_api_server_connector_v2.api.orders_api import OrdersApi as OrdersApi
from public_api_server_connector_v2.api.specification_api import SpecificationApi as SpecificationApi
from public_api_server_connector_v2.api.v1_api import V1Api as V1Api

# import ApiClient
from public_api_server_connector_v2.api_response import ApiResponse as ApiResponse
from public_api_server_connector_v2.api_client import ApiClient as ApiClient
from public_api_server_connector_v2.configuration import Configuration as Configuration
from public_api_server_connector_v2.exceptions import OpenApiException as OpenApiException
from public_api_server_connector_v2.exceptions import ApiTypeError as ApiTypeError
from public_api_server_connector_v2.exceptions import ApiValueError as ApiValueError
from public_api_server_connector_v2.exceptions import ApiKeyError as ApiKeyError
from public_api_server_connector_v2.exceptions import ApiAttributeError as ApiAttributeError
from public_api_server_connector_v2.exceptions import ApiException as ApiException

# import models into sdk package
from public_api_server_connector_v2.models.address import Address as Address
from public_api_server_connector_v2.models.api_key_create import ApiKeyCreate as ApiKeyCreate
from public_api_server_connector_v2.models.api_key_create_response import ApiKeyCreateResponse as ApiKeyCreateResponse
from public_api_server_connector_v2.models.api_key_get import ApiKeyGet as ApiKeyGet
from public_api_server_connector_v2.models.api_key_patch import ApiKeyPatch as ApiKeyPatch
from public_api_server_connector_v2.models.api_key_update import ApiKeyUpdate as ApiKeyUpdate
from public_api_server_connector_v2.models.api_log_get import ApiLogGet as ApiLogGet
from public_api_server_connector_v2.models.attached_file import AttachedFile as AttachedFile
from public_api_server_connector_v2.models.attached_file_create import AttachedFileCreate as AttachedFileCreate
from public_api_server_connector_v2.models.attached_file_create_or_update import AttachedFileCreateOrUpdate as AttachedFileCreateOrUpdate
from public_api_server_connector_v2.models.attached_file_patch import AttachedFilePatch as AttachedFilePatch
from public_api_server_connector_v2.models.attached_files_inner import AttachedFilesInner as AttachedFilesInner
from public_api_server_connector_v2.models.billing_type import BillingType as BillingType
from public_api_server_connector_v2.models.button_position import ButtonPosition as ButtonPosition
from public_api_server_connector_v2.models.button_size import ButtonSize as ButtonSize
from public_api_server_connector_v2.models.button_target import ButtonTarget as ButtonTarget
from public_api_server_connector_v2.models.category import Category as Category
from public_api_server_connector_v2.models.category_method_options import CategoryMethodOptions as CategoryMethodOptions
from public_api_server_connector_v2.models.category_permissions import CategoryPermissions as CategoryPermissions
from public_api_server_connector_v2.models.content import Content as Content
from public_api_server_connector_v2.models.content_block import ContentBlock as ContentBlock
from public_api_server_connector_v2.models.content_block_create import ContentBlockCreate as ContentBlockCreate
from public_api_server_connector_v2.models.content_block_patch import ContentBlockPatch as ContentBlockPatch
from public_api_server_connector_v2.models.content_block_type_str_enum import ContentBlockTypeStrEnum as ContentBlockTypeStrEnum
from public_api_server_connector_v2.models.content_block_update import ContentBlockUpdate as ContentBlockUpdate
from public_api_server_connector_v2.models.content_blocks_inner import ContentBlocksInner as ContentBlocksInner
from public_api_server_connector_v2.models.content_blocks_inner1 import ContentBlocksInner1 as ContentBlocksInner1
from public_api_server_connector_v2.models.course import Course as Course
from public_api_server_connector_v2.models.course_access_type_str_enum import CourseAccessTypeStrEnum as CourseAccessTypeStrEnum
from public_api_server_connector_v2.models.course_content_block import CourseContentBlock as CourseContentBlock
from public_api_server_connector_v2.models.course_create import CourseCreate as CourseCreate
from public_api_server_connector_v2.models.course_module import CourseModule as CourseModule
from public_api_server_connector_v2.models.course_module_create import CourseModuleCreate as CourseModuleCreate
from public_api_server_connector_v2.models.course_module_patch import CourseModulePatch as CourseModulePatch
from public_api_server_connector_v2.models.course_module_simple import CourseModuleSimple as CourseModuleSimple
from public_api_server_connector_v2.models.course_module_update import CourseModuleUpdate as CourseModuleUpdate
from public_api_server_connector_v2.models.course_module_view_type_str_enum import CourseModuleViewTypeStrEnum as CourseModuleViewTypeStrEnum
from public_api_server_connector_v2.models.course_patch import CoursePatch as CoursePatch
from public_api_server_connector_v2.models.course_payment_type_str_enum import CoursePaymentTypeStrEnum as CoursePaymentTypeStrEnum
from public_api_server_connector_v2.models.course_simple import CourseSimple as CourseSimple
from public_api_server_connector_v2.models.course_submodule import CourseSubmodule as CourseSubmodule
from public_api_server_connector_v2.models.course_submodule_create import CourseSubmoduleCreate as CourseSubmoduleCreate
from public_api_server_connector_v2.models.course_submodule_patch import CourseSubmodulePatch as CourseSubmodulePatch
from public_api_server_connector_v2.models.course_submodule_update import CourseSubmoduleUpdate as CourseSubmoduleUpdate
from public_api_server_connector_v2.models.course_update import CourseUpdate as CourseUpdate
from public_api_server_connector_v2.models.file import File as File
from public_api_server_connector_v2.models.file_update import FileUpdate as FileUpdate
from public_api_server_connector_v2.models.file_upload_result import FileUploadResult as FileUploadResult
from public_api_server_connector_v2.models.folder import Folder as Folder
from public_api_server_connector_v2.models.folder_create import FolderCreate as FolderCreate
from public_api_server_connector_v2.models.folder_update import FolderUpdate as FolderUpdate
from public_api_server_connector_v2.models.http_validation_error import HTTPValidationError as HTTPValidationError
from public_api_server_connector_v2.models.http_method import HttpMethod as HttpMethod
from public_api_server_connector_v2.models.ipn_order_payment import IpnOrderPayment as IpnOrderPayment
from public_api_server_connector_v2.models.ipn_order_payment_response import IpnOrderPaymentResponse as IpnOrderPaymentResponse
from public_api_server_connector_v2.models.ipn_order_refund import IpnOrderRefund as IpnOrderRefund
from public_api_server_connector_v2.models.ipn_order_refund_response import IpnOrderRefundResponse as IpnOrderRefundResponse
from public_api_server_connector_v2.models.ipn_transaction import IpnTransaction as IpnTransaction
from public_api_server_connector_v2.models.lesson_type_str_enum import LessonTypeStrEnum as LessonTypeStrEnum
from public_api_server_connector_v2.models.location_inner import LocationInner as LocationInner
from public_api_server_connector_v2.models.marketplace_buyer import MarketplaceBuyer as MarketplaceBuyer
from public_api_server_connector_v2.models.module_lesson import ModuleLesson as ModuleLesson
from public_api_server_connector_v2.models.module_lesson_create import ModuleLessonCreate as ModuleLessonCreate
from public_api_server_connector_v2.models.module_lesson_patch import ModuleLessonPatch as ModuleLessonPatch
from public_api_server_connector_v2.models.module_lesson_patch_attached_files import ModuleLessonPatchAttachedFiles as ModuleLessonPatchAttachedFiles
from public_api_server_connector_v2.models.module_lesson_patch_content import ModuleLessonPatchContent as ModuleLessonPatchContent
from public_api_server_connector_v2.models.module_lesson_simple import ModuleLessonSimple as ModuleLessonSimple
from public_api_server_connector_v2.models.module_lesson_update import ModuleLessonUpdate as ModuleLessonUpdate
from public_api_server_connector_v2.models.portal_info import PortalInfo as PortalInfo
from public_api_server_connector_v2.models.portal_member_base import PortalMemberBase as PortalMemberBase
from public_api_server_connector_v2.models.response_wrapper import ResponseWrapper as ResponseWrapper
from public_api_server_connector_v2.models.response_wrapper_api_key_create_response import ResponseWrapperApiKeyCreateResponse as ResponseWrapperApiKeyCreateResponse
from public_api_server_connector_v2.models.response_wrapper_api_key_get import ResponseWrapperApiKeyGet as ResponseWrapperApiKeyGet
from public_api_server_connector_v2.models.response_wrapper_api_log_get import ResponseWrapperApiLogGet as ResponseWrapperApiLogGet
from public_api_server_connector_v2.models.response_wrapper_bool import ResponseWrapperBool as ResponseWrapperBool
from public_api_server_connector_v2.models.response_wrapper_course import ResponseWrapperCourse as ResponseWrapperCourse
from public_api_server_connector_v2.models.response_wrapper_course_module import ResponseWrapperCourseModule as ResponseWrapperCourseModule
from public_api_server_connector_v2.models.response_wrapper_course_module_simple import ResponseWrapperCourseModuleSimple as ResponseWrapperCourseModuleSimple
from public_api_server_connector_v2.models.response_wrapper_course_simple import ResponseWrapperCourseSimple as ResponseWrapperCourseSimple
from public_api_server_connector_v2.models.response_wrapper_course_submodule import ResponseWrapperCourseSubmodule as ResponseWrapperCourseSubmodule
from public_api_server_connector_v2.models.response_wrapper_file import ResponseWrapperFile as ResponseWrapperFile
from public_api_server_connector_v2.models.response_wrapper_file_upload_result import ResponseWrapperFileUploadResult as ResponseWrapperFileUploadResult
from public_api_server_connector_v2.models.response_wrapper_folder import ResponseWrapperFolder as ResponseWrapperFolder
from public_api_server_connector_v2.models.response_wrapper_int import ResponseWrapperInt as ResponseWrapperInt
from public_api_server_connector_v2.models.response_wrapper_ipn_order_payment_response import ResponseWrapperIpnOrderPaymentResponse as ResponseWrapperIpnOrderPaymentResponse
from public_api_server_connector_v2.models.response_wrapper_ipn_order_refund_response import ResponseWrapperIpnOrderRefundResponse as ResponseWrapperIpnOrderRefundResponse
from public_api_server_connector_v2.models.response_wrapper_list_api_key_get import ResponseWrapperListApiKeyGet as ResponseWrapperListApiKeyGet
from public_api_server_connector_v2.models.response_wrapper_list_api_log_get import ResponseWrapperListApiLogGet as ResponseWrapperListApiLogGet
from public_api_server_connector_v2.models.response_wrapper_list_category import ResponseWrapperListCategory as ResponseWrapperListCategory
from public_api_server_connector_v2.models.response_wrapper_list_content_block import ResponseWrapperListContentBlock as ResponseWrapperListContentBlock
from public_api_server_connector_v2.models.response_wrapper_list_course_module_simple import ResponseWrapperListCourseModuleSimple as ResponseWrapperListCourseModuleSimple
from public_api_server_connector_v2.models.response_wrapper_list_course_simple import ResponseWrapperListCourseSimple as ResponseWrapperListCourseSimple
from public_api_server_connector_v2.models.response_wrapper_list_course_submodule import ResponseWrapperListCourseSubmodule as ResponseWrapperListCourseSubmodule
from public_api_server_connector_v2.models.response_wrapper_list_file import ResponseWrapperListFile as ResponseWrapperListFile
from public_api_server_connector_v2.models.response_wrapper_list_folder import ResponseWrapperListFolder as ResponseWrapperListFolder
from public_api_server_connector_v2.models.response_wrapper_list_module_lesson_simple import ResponseWrapperListModuleLessonSimple as ResponseWrapperListModuleLessonSimple
from public_api_server_connector_v2.models.response_wrapper_list_str import ResponseWrapperListStr as ResponseWrapperListStr
from public_api_server_connector_v2.models.response_wrapper_module_lesson import ResponseWrapperModuleLesson as ResponseWrapperModuleLesson
from public_api_server_connector_v2.models.response_wrapper_module_lesson_simple import ResponseWrapperModuleLessonSimple as ResponseWrapperModuleLessonSimple
from public_api_server_connector_v2.models.response_wrapper_token_info import ResponseWrapperTokenInfo as ResponseWrapperTokenInfo
from public_api_server_connector_v2.models.result import Result as Result
from public_api_server_connector_v2.models.token_info import TokenInfo as TokenInfo
from public_api_server_connector_v2.models.validation_error import ValidationError as ValidationError




# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from public_api_server_connector_v2.models.ipn_order_refund import IpnOrderRefund

class TestIpnOrderRefund(unittest.TestCase):
    """IpnOrderRefund unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> IpnOrderRefund:
        """Test IpnOrderRefund
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `IpnOrderRefund`
        """
        model = IpnOrderRefund()
        if include_optional:
            return IpnOrderRefund(
                id = '',
                transaction = public_api_server_connector_v2.models.ipn_transaction.IpnTransaction(
                    amount = 1.337, 
                    id = '', )
            )
        else:
            return IpnOrderRefund(
                id = '',
        )
        """

    def testIpnOrderRefund(self):
        """Test IpnOrderRefund"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from public_api_server_connector_v2.models.course_access_type_str_enum import CourseAccessTypeStrEnum
from public_api_server_connector_v2.models.course_module_view_type_str_enum import CourseModuleViewTypeStrEnum
from public_api_server_connector_v2.models.course_payment_type_str_enum import CoursePaymentTypeStrEnum
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python

class CourseCreate(BaseModel):
    """
    CourseCreate
    """ # noqa: E501
    title: StrictStr = Field(description="Title of the course")
    image_id: Optional[StrictStr] = Field(default=None, description="ID of the course image on file service")
    description: Optional[StrictStr] = Field(default='', description="Description of the course")
    url: Optional[StrictStr] = Field(default='', description="URL of the sales page, if landing page is not used")
    payload: Optional[StrictStr] = Field(default='', description="Additional payload for the course, text or HTML content")
    module_view_type: Optional[CourseModuleViewTypeStrEnum] = None
    payment_type: Optional[CoursePaymentTypeStrEnum] = None
    course_access_type: Optional[CourseAccessTypeStrEnum] = None
    number_days_access: Optional[StrictInt] = 0
    is_active: StrictBool = Field(description="Whether the course is active and available for users")
    is_secret: StrictBool = Field(description="Whether the course is secret and not listed publicly on dashboard, does not affect visibility in the mobile app")
    is_archived: StrictBool = Field(description="Whether the course is archived (deleted and to be removed from database)")
    is_displayed_in_app: StrictBool = Field(description="Whether the course is displayed in mobile app, unrelated to the course visibility in the web app")
    is_offline_downloadable: StrictBool = Field(description="Whether the course can be downloaded for offline access in the mobile app")
    available_at: Optional[StrictInt] = None
    launch_date_enabled: Optional[StrictBool] = False
    launch_date: Optional[StrictInt] = 0
    order: Optional[StrictInt] = Field(default=None, description="Order of the course in the list. If not provided, it will be set to the last position.")
    __properties: ClassVar[List[str]] = ["title", "image_id", "description", "url", "payload", "module_view_type", "payment_type", "course_access_type", "number_days_access", "is_active", "is_secret", "is_archived", "is_displayed_in_app", "is_offline_downloadable", "available_at", "launch_date_enabled", "launch_date", "order"]

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CourseCreate from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CourseCreate from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "title": obj.get("title"),
            "image_id": obj.get("image_id"),
            "description": obj.get("description") if obj.get("description") is not None else '',
            "url": obj.get("url") if obj.get("url") is not None else '',
            "payload": obj.get("payload") if obj.get("payload") is not None else '',
            "module_view_type": obj.get("module_view_type"),
            "payment_type": obj.get("payment_type"),
            "course_access_type": obj.get("course_access_type"),
            "number_days_access": obj.get("number_days_access") if obj.get("number_days_access") is not None else 0,
            "is_active": obj.get("is_active"),
            "is_secret": obj.get("is_secret"),
            "is_archived": obj.get("is_archived"),
            "is_displayed_in_app": obj.get("is_displayed_in_app"),
            "is_offline_downloadable": obj.get("is_offline_downloadable"),
            "available_at": obj.get("available_at"),
            "launch_date_enabled": obj.get("launch_date_enabled") if obj.get("launch_date_enabled") is not None else False,
            "launch_date": obj.get("launch_date") if obj.get("launch_date") is not None else 0,
            "order": obj.get("order")
        })
        return _obj





"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from setuptools import setup, find_packages  # noqa: H301

# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools
NAME = "public-api-server-connector-v2"
VERSION = "1.0.0+2522689235"
PYTHON_REQUIRES = ">= 3.10"
REQUIRES = [
    "python-dateutil >= 2.8.2",
    "aiohttp >= 3.8.4",
    "aiohttp-retry >= 2.8.3",
    "pydantic >= 2.11",
    "typing-extensions >= 4.7.1",
]

setup(
    name=NAME,
    version=VERSION,
    description="Mentortools Public API",
    author="OpenAPI Generator community",
    author_email="team@openapitools.org",
    url="",
    keywords=["OpenAPI", "OpenAPI-Generator", "Mentortools Public API"],
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    long_description_content_type='text/markdown',
    long_description="""\
    Mentortools public API service
    """,  # noqa: E501
    package_data={"public_api_server_connector_v2": ["py.typed"]},
)



# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class BillingType(str, Enum):
    """
    An enumeration.
    """

    """
    allowed enum values
    """
    SINGLE_PAYMENT = 'single_payment'
    SUBSCRIPTION = 'subscription'
    INSTALLMENT = 'installment'
    FREE = 'free'
    FAKE = 'fake'
    GIFT = 'gift'
    SINGLE_PAYMENT_IMPORTED = 'single_payment_imported'
    SUBSCRIPTION_IMPORTED = 'subscription_imported'
    INSTALLMENT_IMPORTED = 'installment_imported'
    FREE_IMPORTED = 'free_imported'
    FAKE_IMPORTED = 'fake_imported'
    GIFT_IMPORTED = 'gift_imported'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of BillingType from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from public_api_server_connector_v2.models.response_wrapper_token_info import ResponseWrapperTokenInfo

class TestResponseWrapperTokenInfo(unittest.TestCase):
    """ResponseWrapperTokenInfo unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResponseWrapperTokenInfo:
        """Test ResponseWrapperTokenInfo
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ResponseWrapperTokenInfo`
        """
        model = ResponseWrapperTokenInfo()
        if include_optional:
            return ResponseWrapperTokenInfo(
                done = True,
                result = public_api_server_connector_v2.models.token_info.TokenInfo(
                    api_key = public_api_server_connector_v2.models.api_key_get.ApiKeyGet(
                        name = '', 
                        id = 56, 
                        portal_id = 56, 
                        permissions = {
                            'key' : public_api_server_connector_v2.models.category_permissions.CategoryPermissions(
                                create = True, 
                                read = True, 
                                update = True, 
                                delete = True, )
                            }, 
                        openapi_specification_url = '', 
                        created_at = 56, 
                        last_used_at = 56, 
                        updated_at = 56, 
                        expires_at = 56, 
                        revoked_at = 56, ), 
                    portal = public_api_server_connector_v2.models.portal_info.PortalInfo(
                        id = 56, 
                        domain = '', ), 
                    owner = public_api_server_connector_v2.models.portal_member_base.PortalMemberBase(
                        id = 56, 
                        email = '', ), ),
                error = ''
            )
        else:
            return ResponseWrapperTokenInfo(
                done = True,
        )
        """

    def testResponseWrapperTokenInfo(self):
        """Test ResponseWrapperTokenInfo"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
